@@ -20,7 +20,7 @@ Numpy is a package used for scientific computing in Python and an efficient cont
 
 @em Requirements:
 
-    - Python 3.5 or higher
+    - Python 3.7 or higher
     - NumPy
 
 """
@@ -31,6 +31,8 @@ from functools import wraps
 
 import numpy as np
 
+from gribapi.errors import GribInternalError
+
 from . import errors
 from .bindings import ENC
 from .bindings import __version__ as bindings_version  # noqa
@@ -970,7 +972,7 @@ def grib_get_double(msgid, key):
     return value_p[0]
 
 
-@require(msgid=int, key=str, value=(int, float, np.float16, np.float32, str))
+@require(msgid=int, key=str, value=(int, float, np.float16, np.float32, np.int64, str))
 def grib_set_long(msgid, key, value):
     """
     @brief Set the integer value for a key in a message.
@@ -1696,9 +1698,7 @@ def grib_set_key_vals(gribid, key_vals):
             if not isinstance(kv, str):
                 raise TypeError("Invalid list/tuple element type '%s'" % kv)
             if "=" not in str(kv):
-                raise errors.GribInternalError(
-                    "Invalid list/tuple element format '%s'" % kv
-                )
+                raise GribInternalError("Invalid list/tuple element format '%s'" % kv)
             if len(key_vals_str) > 0:
                 key_vals_str += ","
             key_vals_str += kv
@@ -2060,7 +2060,7 @@ def grib_set(msgid, key, value):
     @param value      scalar value to set for key
     @exception CodesInternalError
     """
-    if isinstance(value, int):
+    if isinstance(value, (int, np.int64)):
         grib_set_long(msgid, key, value)
     elif isinstance(value, (float, np.float16, np.float32, np.float64)):
         grib_set_double(msgid, key, value)
@@ -2073,7 +2073,7 @@ def grib_set(msgid, key, value):
         hint = ""
         if hasattr(value, "__iter__"):
             hint = " (Hint: for array keys use codes_set_array(msgid, key, value))"
-        raise errors.GribInternalError(
+        raise GribInternalError(
             "Invalid type of value when setting key '%s'%s." % (key, hint)
         )
 
@@ -2109,7 +2109,7 @@ def grib_set_array(msgid, key, value):
         try:
             int(val0)
         except (ValueError, TypeError):
-            raise errors.GribInternalError(
+            raise GribInternalError(
                 "Invalid type of value when setting key '%s'." % key
             )
         grib_set_long_array(msgid, key, value)
@@ -2166,9 +2166,7 @@ def grib_index_select(indexid, key, value):
     elif isinstance(value, str):
         grib_index_select_string(indexid, key, value)
     else:
-        raise errors.GribInternalError(
-            "Invalid type of value when setting key '%s'." % key
-        )
+        raise GribInternalError("Invalid type of value when setting key '%s'." % key)
 
 
 @require(indexid=int, filename=str)
