@@ -308,7 +308,7 @@ def test_grib_keys_iterator_skip():
     eccodes.codes_skip_coded(iterid)
     while eccodes.codes_keys_iterator_next(iterid):
         count += 1
-    assert count == 141
+    assert count > 140
     eccodes.codes_keys_iterator_delete(iterid)
     eccodes.codes_release(gid)
 
@@ -446,7 +446,23 @@ def test_grib_ecc_1007():
     eccodes.codes_release(gid)
 
 
-def test_grib_float_array():
+def test_grib_set_bitmap():
+    gid = eccodes.codes_grib_new_from_samples("GRIB2")
+    missing = np.Infinity
+    eccodes.codes_set(gid, "bitmapPresent", 1)
+    eccodes.codes_set(gid, "missingValue", missing)
+    # Grid with 100 points 2 of which are missing
+    values = np.ones((100,))
+    values[2] = missing
+    values[4] = missing
+    eccodes.codes_set_values(gid, values)
+    assert eccodes.codes_get(gid, "numberOfDataPoints") == 100
+    assert eccodes.codes_get(gid, "numberOfCodedValues") == 98
+    assert eccodes.codes_get(gid, "numberOfMissing") == 2
+    eccodes.codes_release(gid)
+
+
+def test_grib_set_float_array():
     gid = eccodes.codes_grib_new_from_samples("regular_ll_sfc_grib2")
     for ftype in (float, np.float16, np.float32, np.float64):
         values = np.ones((100000,), ftype)
@@ -456,6 +472,16 @@ def test_grib_float_array():
         assert (eccodes.codes_get_values(gid) == 1.0).all()
 
 
+def test_grib_set_np_int64():
+    gid = eccodes.codes_grib_new_from_samples("regular_gg_sfc_grib2")
+    eccodes.codes_set(gid, "productDefinitionTemplateNumber", 1)
+    eccodes.codes_set(gid, "number", np.int64(17))
+    assert eccodes.codes_get_long(gid, "number") == 17
+    eccodes.codes_set_long(gid, "number", np.int64(16))
+    assert eccodes.codes_get_long(gid, "number") == 16
+    eccodes.codes_release(gid)
+
+
 def test_gribex_mode():
     eccodes.codes_gribex_mode_on()
     eccodes.codes_gribex_mode_off()
@@ -563,7 +589,7 @@ def test_grib_uuid_get_set():
 
 def test_grib_dump(tmp_path):
     gid = eccodes.codes_grib_new_from_samples("GRIB2")
-    p = tmp_path / "dump.txt"
+    p = tmp_path / "dump_grib.txt"
     with open(p, "w") as fout:
         eccodes.codes_dump(gid, fout)
         eccodes.codes_dump(gid, fout, "debug")
@@ -743,6 +769,15 @@ def test_bufr_extract_headers():
     assert math.isclose(header["localLongitude"], 151.83)
 
 
+def test_bufr_dump(tmp_path):
+    bid = eccodes.codes_bufr_new_from_samples("BUFR4")
+    eccodes.codes_set(bid, "unpack", 1)
+    p = tmp_path / "dump_bufr.txt"
+    with open(p, "w") as fout:
+        eccodes.codes_dump(bid, fout, "json")
+    eccodes.codes_release(bid)
+
+
 # ---------------------------------------------
 # Experimental features
 # ---------------------------------------------
